function [LAMBDA,V,r1]=initial_periodic_orbits1(k,mu)

% mu:  The mass ratio between the two bodies

% k = 1: ASSUMES THAT x+mu>1 (=> x+mu>0)
% k = 2: ASSUMES THAT 0<x+mu<1 
% k = 3: ASSUMES THAT x+mu<0 (=> x+mu<1)

if k==1,
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% THIS PART ASSUMES THAT x+mu>1 (=> x+mu>0) %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% Computation of the equilibria assuming x' = y = y' = 0

A5=1;
A4=-2+4*mu;
A3=(-1+mu)^2+(2*(-2+2*mu))*mu+mu^2;
A2=2*(-1+mu)^2*mu+(-2+2*mu)*mu^2-1;
A1=(-1+mu)^2*mu^2-(1-mu)*(-2+2*mu)-2*mu^2;
A0=-mu^3-(1-mu)*(-1+mu)^2;

p=[A5 A4 A3 A2 A1 A0];

%%% The roots of p correspond to equilibria of the form (x,0,0,0)
%%% p(x) = sum_{j=0}^5 Aj x^j = 0

R=sort(roots(p));
R= R(R == real(R));

r1=R(1);

%%% Let us now compute the Jacobian Df(r1,0,0,0)

x=r1; y=0;

display('Case 1: x+mu>1 (=> x+mu>0)') 
display(['The equilibrium is X=(',num2str(x),',0,0,0)']) 

[Df]=jacobian(x,y,mu);

[V,LAMBDA]=eigs(Df);
LAMBDA=diag(LAMBDA);

end

if k==2,
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% THIS PART ASSUMES THAT 0<x+mu<1 %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% Computation of the equilibria assuming x' = y = y' = 0

A5=1;
A4=-2+4*mu;
A3=(-1+mu)^2+(2*(-2+2*mu))*mu+mu^2;
A2=2*(-1+mu)^2*mu+(-2+2*mu)*mu^2-1+2*mu;
A1=(-1+mu)^2*mu^2-(1-mu)*(-2+2*mu)+2*mu^2;
A0=mu^3-(1-mu)*(-1+mu)^2;

p=[A5 A4 A3 A2 A1 A0];

%%% The roots of p correspond to equilibria of the form (x,0,0,0)
%%% p(x) = sum_{j=0}^5 Aj x^j = 0

R=sort(roots(p));
R= R(R == real(R));

r1=R(1);

%%% Let us now compute the Jacobian Df(r1,0,0,0)

x=r1; y=0;

display('Case 2: 0<x+mu<1') 
display(['The equilibrium is X=(',num2str(x),',0,0,0)']) 

[Df]=jacobian(x,y,mu);

[V,LAMBDA]=eigs(Df);
LAMBDA=diag(LAMBDA);

end

if k==3,
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% THIS PART ASSUMES THAT x+mu<0 (=> x+mu<1) %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% Computation of the equilibria assuming x' = y = y' = 0

A5=1;
A4=-2+4*mu;
A3=(-1+mu)^2+(2*(-2+2*mu))*mu+mu^2;
A2=2*(-1+mu)^2*mu+(-2+2*mu)*mu^2+1;
A1=(-1+mu)^2*mu^2+(1-mu)*(-2+2*mu)+2*mu^2;
A0=mu^3+(1-mu)*(-1+mu)^2;

p=[A5 A4 A3 A2 A1 A0];

%%% The roots of p correspond to equilibria of the form (x,0,0,0)
%%% p(x) = sum_{j=0}^5 Aj x^j = 0

R=sort(roots(p));
R= R(R == real(R));

r1=R(1);

%%% Let us now compute the Jacobian Df(r1,0,0,0)

x=r1; y=0;

display('Case 3: x+mu<0 (=> x+mu<1)') 
display(['The equilibrium is X=(',num2str(x),',0,0,0)']) 

[Df]=jacobian(x,y,mu);

[V,LAMBDA]=eigs(Df);
LAMBDA=diag(LAMBDA);

end

end

