function [DF] = int_DF_CR3BP(x,L,mu,K)
% Inputs: 
%  1) x = [x1;x2;x3;x4;x5;x6] : the vector of Fourier coefficients
%  2) L : the frequency of the periodic orbit
%  3) mu : the mass ratio
%  4) K : case differentiating the value of x_1(0)+mu
%        K = 1: ASSUMES THAT x_1(0)+mu>1
%        K = 2: ASSUMES THAT 0<x_1(0)+mu<1 
%        K = 3: ASSUMES THAT x_1(0)+mu<0

m=length(x)/6;

mu=intval(mu);

a1=x(1:m);
a2=x(m+1:2*m);
a3=x(2*m+1:3*m);
a4=x(3*m+1:4*m);
a5=x(4*m+1:5*m);
a6=x(5*m+1:end);

a1_ext=intval([zeros(m,1);flipdim(a1(2:m),1);a1;zeros(m,1)]);
a2_ext=intval([zeros(m,1);-flipdim(a2(2:m),1);a2;zeros(m,1)]);
a3_ext=intval([zeros(m,1);-flipdim(a3(2:m),1);a3;zeros(m,1)]);
a4_ext=intval([zeros(m,1);flipdim(a4(2:m),1);a4;zeros(m,1)]);
a5_ext=intval([zeros(m,1);flipdim(a5(2:m),1);a5;zeros(m,1)]);
a6_ext=intval([zeros(m,1);flipdim(a6(2:m),1);a6;zeros(m,1)]);

I=intval(eye(m));
Z=intval(zeros(m));
D=intval(L)*intval(diag(0:m-1));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Block 1: [d(F_1)/d(a1) ... d(F_1)/d(a6)] %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% d(F_1)/d(a2)
B_2=-I;
B_2(1,1)=intval(1);

L_1=[D,B_2,Z,Z,Z,Z];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Block 2: [d(F_2)/d(a1) ... d(F_2)/d(a6)] %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% d(F_2)/d(a1)
B_7=Z;
a53=int_cubic(a5_ext,a5_ext,a5_ext);
a63=int_cubic(a6_ext,a6_ext,a6_ext);

for j=1:m;
    l=j-1;
    if l==0;
        B_7(1:m,j)=-(1-mu)*a53(abs((0:m-1)-l)+1,1)-mu*a63(abs((0:m-1)-l)+1,1);
    else
        B_7(1:m,j)=-(1-mu)*a53(abs((0:m-1)-l)+1,1)-(1-mu)*a53(abs((0:m-1)+l)+1,1)-mu*a63(abs((0:m-1)-l)+1,1)-mu*a63(abs((0:m-1)+l)+1,1);
    end
end

B_7=I+B_7;

% d(F_2)/d(a5)

B_11=Z;
a52=int_quadratic(a5_ext,a5_ext);
a52a1=int_cubic(a5_ext,a5_ext,a1_ext);

for j=1:m;
    l=j-1;
    if l==0;
        B_11(1:m,j)=-3*(1-mu)*a52a1(abs((0:m-1)-l)+1,1)-3*(mu-mu^2)*a52(abs((0:m-1)-l)+1,1);
    else
        B_11(1:m,j)=-3*(1-mu)*a52a1(abs((0:m-1)-l)+1,1)-3*(mu-mu^2)*a52(abs((0:m-1)-l)+1,1)-3*(1-mu)*a52a1(abs((0:m-1)+l)+1,1)-3*(mu-mu^2)*a52(abs((0:m-1)+l)+1,1);
    end
end

% d(F_2)/d(a6)

B_12=Z;
a62=int_quadratic(a6_ext,a6_ext);
a62a1=int_cubic(a6_ext,a6_ext,a1_ext);

for j=1:m;
    l=j-1;
    if l==0;
        B_12(1:m,j)=-3*mu*a62a1(abs((0:m-1)-l)+1,1)+3*(mu-mu^2)*a62(abs((0:m-1)-l)+1,1);
    else
        B_12(1:m,j)=-3*mu*a62a1(abs((0:m-1)-l)+1,1)+3*(mu-mu^2)*a62(abs((0:m-1)-l)+1,1)-3*mu*a62a1(abs((0:m-1)+l)+1,1)+3*(mu-mu^2)*a62(abs((0:m-1)+l)+1,1);
    end
end

L_2=[B_7,D,Z,2*I,B_11,B_12];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Block 3: [d(F_3)/d(a1) ... d(F_3)/d(a6)] %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

L_3=[Z,Z,D,I,Z,Z];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Block 4: [d(F_4)/d(a1) ... d(F_4)/d(a6)] %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% d(F_4)/d(a2)
B_20=2*I;
B_20(1,:)=zeros(1,m);

% d(F_4)/d(a3)
B_21=Z;

for j=1:m;
    l=j-1;
    if l==0;
        B_21(1:m,j)=(1-mu)*a53(abs((0:m-1)-l)+1,1)+mu*a63(abs((0:m-1)-l)+1,1);
    else
        B_21(1:m,j)=(1-mu)*a53(abs((0:m-1)-l)+1,1)-(1-mu)*a53(abs((0:m-1)+l)+1,1)+mu*a63(abs((0:m-1)-l)+1,1)-mu*a63(abs((0:m-1)+l)+1,1);
    end
end

B_21=B_21-I;
B_21(1,:)=zeros(1,m);
B_21(1,1)=intval(1);

% d(F_4)/d(a5)
B_23=Z;
a52a3_ext=int_cubic_ext(a3_ext,a5_ext,a5_ext);

for ell=0:m-1;
    if ell==0;
        B_23(1:m,ell+1)=3*(1-mu)*a52a3_ext((0:m-1)-ell+2*m);
    else % ell>0;
        B_23(1:m,ell+1)=3*(1-mu)*(a52a3_ext((0:m-1)-ell+2*m)+a52a3_ext((0:m-1)+ell+2*m));
    end
end

%We change the first line
B_23(1,:)=zeros(1,m);

% d(F_4)/d(a6)
B_24=Z;
a62a3_ext=int_cubic_ext(a3_ext,a6_ext,a6_ext);

for ell=0:m-1;
    if ell==0;
        B_24(1:m,ell+1)=3*mu*a62a3_ext((0:m-1)-ell+2*m);
    else
        B_24(1:m,ell+1)=3*mu*(a62a3_ext((0:m-1)-ell+2*m)+a62a3_ext((0:m-1)+ell+2*m));
    end
end

%We change the first line
B_24(1,:)=zeros(1,m);

L_4=[Z,B_20,B_21,D,B_23,B_24];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Block 5: [d(F_5)/d(a1) ... d(F_5)/d(a6)] %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% d(F_5)/d(a1)
B_25=Z;
a53a2_ext=int_quartic_ext(a2_ext,a5_ext,a5_ext,a5_ext);

for j=1:m;
    l=j-1;
    if l==0;
        B_25(1:m,j)=a53a2_ext((0:m-1)-l+2*m);
    else
        B_25(1:m,j)=a53a2_ext((0:m-1)-l+2*m)+a53a2_ext((0:m-1)+l+2*m);
    end
end

%We change the first line
x5_0=a5(1)+2*sum(a5(2:end));
if K==3
    B_25(1,1)=-x5_0;
    B_25(1,2:end)=-2*x5_0;
else
    B_25(1,1)=x5_0;
    B_25(1,2:end)=2*x5_0;
end 

% d(F_5)/d(a2)
B_26=Z;
a53a1=int_quartic(a5_ext,a5_ext,a5_ext,a1_ext);

for j=1:m;
    l=j-1;
    if l==0;
        B_26(1:m,j)=a53a1(abs((0:m-1)-l)+1,1)+mu*a53(abs((0:m-1)-l)+1,1);
    else
        B_26(1:m,j)=a53a1(abs((0:m-1)-l)+1,1)+mu*a53(abs((0:m-1)-l)+1,1)-a53a1(abs((0:m-1)+l)+1,1)-mu*a53(abs((0:m-1)+l)+1,1);
    end
end

%We change the first line
B_26(1,:)=zeros(1,m);

% d(F_5)/d(a3)
B_27=Z;
a53a4=int_quartic(a5_ext,a5_ext,a5_ext,a4_ext);

for j=1:m;
    l=j-1;
    if l==0;
        B_27(1:m,j)=a53a4(abs((0:m-1)-l)+1,1);
    else
        B_27(1:m,j)=a53a4(abs((0:m-1)-l)+1,1)-a53a4(abs((0:m-1)+l)+1,1);
    end
end

%We change the first line
B_27(1,:)=zeros(1,m);

% d(F_5)/d(a4)
B_28=Z;
a53a3_ext=int_quartic_ext(a3_ext,a5_ext,a5_ext,a5_ext);

for j=1:m;
    l=j-1;
    if l==0;
        B_28(1:m,j)=a53a3_ext((0:m-1)-l+2*m);
    else
        B_28(1:m,j)=a53a3_ext((0:m-1)-l+2*m)+a53a3_ext((0:m-1)+l+2*m);
    end
end

%We change the first line
B_28(1,:)=zeros(1,m);

% d(F_5)/d(a5)
B_29=Z;
a52a1a2_ext=int_quartic_ext(a2_ext,a5_ext,a1_ext,a5_ext);
a52a3a4_ext=int_quartic_ext(a3_ext,a5_ext,a5_ext,a4_ext);
a52a2_ext=int_cubic_ext(a2_ext,a5_ext,a5_ext);

for j=1:m;
    l=j-1;
    if l==0;
        B_29(1:m,j)=3*a52a1a2_ext((0:m-1)-l+2*m)+3*mu*a52a2_ext((0:m-1)-l+2*m)+3*a52a3a4_ext((0:m-1)-l+2*m);
    else
        B_29(1:m,j)=3*a52a1a2_ext((0:m-1)-l+2*m)+3*mu*a52a2_ext((0:m-1)-l+2*m)+3*a52a3a4_ext((0:m-1)-l+2*m)...
                       +3*a52a1a2_ext((0:m-1)+l+2*m)+3*mu*a52a2_ext((0:m-1)+l+2*m)+3*a52a3a4_ext((0:m-1)+l+2*m);
    end
end

B_29=B_29+D;

%We change the first line
x1_0=a1(1)+2*sum(a1(2:end));
if K==3
    B_29(1,1)=-(x1_0+mu);
    B_29(1,2:end)=-2*(x1_0+mu);
else
    B_29(1,1)=x1_0+mu;
    B_29(1,2:end)=2*(x1_0+mu);
end

L_5=[B_25,B_26,B_27,B_28,B_29,Z];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Block 6: [d(F_6)/d(a1) ... d(F_6)/d(a6)] %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

% d(F_6)/d(a1)
B_31=Z;
a63a2_ext=int_quartic_ext(a2_ext,a6_ext,a6_ext,a6_ext);

for j=1:m;
    l=j-1;
    if l==0;
        B_31(1:m,j)=a63a2_ext((0:m-1)-l+2*m);
    else
        B_31(1:m,j)=a63a2_ext((0:m-1)-l+2*m)+a63a2_ext((0:m-1)+l+2*m);
    end
end

%We change the first line

x6_0=a6(1)+2*sum(a6(2:end));
if K==1
    B_31(1,1)=x6_0;
    B_31(1,2:end)=2*x6_0;
else
    B_31(1,1)=-x6_0;
    B_31(1,2:end)=-2*x6_0;
end

% d(F_6)/d(a2)
B_32=Z;
a63a1=int_quartic(a6_ext,a6_ext,a6_ext,a1_ext);

for j=1:m;
    l=j-1;
    if l==0;
        B_32(1:m,j)=a63a1(abs((0:m-1)-l)+1,1)+(mu-1)*a63(abs((0:m-1)-l)+1,1);
    else
        B_32(1:m,j)=a63a1(abs((0:m-1)-l)+1,1)+(mu-1)*a63(abs((0:m-1)-l)+1,1)-a63a1(abs((0:m-1)+l)+1,1)-(mu-1)*a63(abs((0:m-1)+l)+1,1);
    end
end

%We change the first line
B_32(1,:)=zeros(1,m);

% d(F_6)/d(a3)
B_33=Z;
a63a4=int_quartic(a6_ext,a6_ext,a6_ext,a4_ext);

for j=1:m;
    l=j-1;
    if l==0;
        B_33(1:m,j)=a63a4(abs((0:m-1)-l)+1,1);
    else
        B_33(1:m,j)=a63a4(abs((0:m-1)-l)+1,1)-a63a4(abs((0:m-1)+l)+1,1);
    end
end

%We change the first line
B_33(1,:)=zeros(1,m);

% d(F_6)/d(a4)
B_34=Z;
a63a3_ext=int_quartic_ext(a3_ext,a6_ext,a6_ext,a6_ext);

for j=1:m;
    l=j-1;
    if l==0;
        B_34(1:m,j)=a63a3_ext((0:m-1)-l+2*m);
    else
        B_34(1:m,j)=a63a3_ext((0:m-1)-l+2*m)+a63a3_ext((0:m-1)+l+2*m);
    end
end

%We change the first line
B_34(1,:)=zeros(1,m);

% d(F_6)/d(a6)
B_36=Z;
a62a1a2_ext=int_quartic_ext(a2_ext,a6_ext,a1_ext,a6_ext);
a62a3a4_ext=int_quartic_ext(a3_ext,a6_ext,a6_ext,a4_ext);
a62a2_ext=int_cubic_ext(a2_ext,a6_ext,a6_ext);

for j=1:m;
    l=j-1;
    if l==0;
        B_36(1:m,j)=3*a62a1a2_ext((0:m-1)-l+2*m)+3*(mu-1)*a62a2_ext((0:m-1)-l+2*m)+3*a62a3a4_ext((0:m-1)-l+2*m);
    else
        B_36(1:m,j)=3*a62a1a2_ext((0:m-1)-l+2*m)+3*(mu-1)*a62a2_ext((0:m-1)-l+2*m)+3*a62a3a4_ext((0:m-1)-l+2*m)...
                    +3*a62a1a2_ext((0:m-1)+l+2*m)+3*(mu-1)*a62a2_ext((0:m-1)+l+2*m)+3*a62a3a4_ext((0:m-1)+l+2*m);
    end
end

B_36=B_36+D;

%We change the first line

if K==1
    B_36(1,1)=(x1_0+mu-1);
    B_36(1,2:end)=2*(x1_0+mu-1);
else
    B_36(1,1)=-(x1_0+mu-1);
    B_36(1,2:end)=-2*(x1_0+mu-1);
end

L_6=[B_31,B_32,B_33,B_34,Z,B_36];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%       DF final       %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%

DF=[L_1;L_2;L_3;L_4;L_5;L_6];

end

