function [F] = int_F_CR3BP(x,L,mu,K)
% Inputs: 
%  1) x = [x1;x2;x3;x4;x5;x6] : the vector of Fourier coefficients
%  2) L : the frequency of the periodic orbit
%  3) mu : the mass ratio
%  4) K : case differentiating the value of x_1(0)+mu
%        K = 1: ASSUMES THAT x_1(0)+mu>1
%        K = 2: ASSUMES THAT 0<x_1(0)+mu<1 
%        K = 3: ASSUMES THAT x_1(0)+mu<0

m=length(x)/6;
i1=intval(1);
i2=intval(2);
imu=intval(mu);

Lk=intval(L)*intval(0:m-1)';

a1=intval(x(1:m));        % cosine
a2=intval(x(m+1:2*m));    % sine
a3=intval(x(2*m+1:3*m));  % sine
a4=intval(x(3*m+1:4*m));  % cosine
a5=intval(x(4*m+1:5*m));  % cosine
a6=intval(x(5*m+1:6*m));  % cosine

ta1=[flip(a1(2:m),1);a1];
ta2=[-flip(a2(2:m),1);a2];
ta3=[-flip(a3(2:m),1);a3];
ta4=[flip(a4(2:m),1);a4];
ta5=[flip(a5(2:m),1);a5];
ta6=[flip(a6(2:m),1);a6];

F_1=-a2+(Lk.*a1); 
F_2=i2*a4+a1-(i1-imu)*(int_quartic(ta1,ta5,ta5,ta5))-(imu-imu^i2)*int_cubic(ta5,ta5,ta5)-imu*int_quartic(ta1,ta6,ta6,ta6)+(imu-imu^2)*int_cubic(ta6,ta6,ta6)+(Lk.*a2);
F_3=a4+(Lk.*a3); 
F_4=i2*a2-a3+(i1-imu)*(int_quartic(ta3,ta5,ta5,ta5))+imu*int_quartic(ta3,ta6,ta6,ta6)+Lk.*a4;
F_5=int_quintic(ta2,ta1,ta5,ta5,ta5)+imu*int_quartic(ta2,ta5,ta5,ta5)+int_quintic(ta3,ta4,ta5,ta5,ta5)+Lk.*a5;
F_6=int_quintic(ta1,ta2,ta6,ta6,ta6)+(imu-i1)*int_quartic(ta2,ta6,ta6,ta6)+int_quintic(ta3,ta4,ta6,ta6,ta6)+Lk.*a6;

x1_0=a1(1)+i2*sum(a1(2:end));
x5_0=a5(1)+i2*sum(a5(2:end));
x6_0=a6(1)+i2*sum(a6(2:end));

F_1(1)=a2(1);
F_4(1)=a3(1);

%%% The following should depend on which case we study
if K==1 % ASSUMES THAT x_1(0)+mu>1 (=> x_1(0)+mu>0)
    eta1=x5_0*(x1_0+imu)-i1;
    eta2=x6_0*(x1_0-i1+imu)-i1;
end

if K==2 % ASSUMES THAT 0<x_1(0)+mu<1
    eta1=x5_0*(x1_0+imu)-i1;
    eta2=-x6_0*(x1_0-i1+imu)-i1;
end

if K==3 % ASSUMES THAT x_1(0)+mu<0  (=> x_1(0)-1+mu<0)
    eta1=-x5_0*(x1_0+imu)-i1;
    eta2=-x6_0*(x1_0-i1+imu)-i1;
end

F_5(1)=eta1;
F_6(1)=eta2;

F=[F_1;F_2;F_3;F_4;F_5;F_6];

end

