function [I,r,success] = int_rad_poly_CR3BP(a,L,mu,nu,m1,K)

% Inputs:
%  1) a = [a1;a2;a3;a4;a5;a6] : the vector of Fourier coefficients
%  2) L : the frequency of the periodic orbit
%  3) mu : the mass ratio
%  4) nu : the exponential decay rate
%  5) m1 : the actual dimension where the modes are non zero is 6*m1
%     this parameter is used to reduce the blowup when computing the norms
%  6) K : case differentiating the value of a1(0)+mu
%        K = 1: ASSUMES THAT a1(0)+mu>1
%        K = 2: ASSUMES THAT 0<a1(0)+mu<1
%        K = 3: ASSUMES THAT a1(0)+mu<0

m=length(a)/6;

i0=intval(0);
nu=intval(nu);
mu=intval(mu);
L=intval(L);

i1=(1:m);
i2=(m+1:2*m);
i3=(2*m+1:3*m);
i4=(3*m+1:4*m);
i5=(4*m+1:5*m);
i6=(5*m+1:6*m);

a1=a(i1);
a2=a(i2);
a3=a(i3);
a4=a(i4);
a5=a(i5);
a6=a(i6);

M=5*m1;

a1_ext=[a1(1:m1);zeros(4*m1,1)];
a2_ext=[a2(1:m1);zeros(4*m1,1)];
a3_ext=[a3(1:m1);zeros(4*m1,1)];
a4_ext=[a4(1:m1);zeros(4*m1,1)];
a5_ext=[a5(1:m1);zeros(4*m1,1)];
a6_ext=[a6(1:m1);zeros(4*m1,1)];

a_ext=[a1_ext;a2_ext;a3_ext;a4_ext;a5_ext;a6_ext];

F_ext=int_F_CR3BP(a_ext,L,mu,K);

F1_ext=[F_ext(1:M);intval(zeros(m-M,1))];
F2_ext=[F_ext(M+1:2*M);intval(zeros(m-M,1))];
F3_ext=[F_ext(2*M+1:3*M);intval(zeros(m-M,1))];
F4_ext=[F_ext(3*M+1:4*M);intval(zeros(m-M,1))];
F5_ext=[F_ext(4*M+1:5*M);intval(zeros(m-M,1))];
F6_ext=[F_ext(5*M+1:end);intval(zeros(m-M,1))];

F1_ext(m1+1:end)=i0;
F2_ext(4*m1-3:end)=i0;
F3_ext(m1+1:end)=i0;
F4_ext(4*m1-3:end)=i0;
F5_ext(5*m1-4:end)=i0;
F6_ext(5*m1-4:end)=i0;

Fm=[F1_ext(1:m);F2_ext(1:m);F3_ext(1:m);F4_ext(1:m);F5_ext(1:m);F6_ext(1:m)];

%display('Computing DF with interval arithmetic.')
iDF=int_DF_CR3BP(a,L,mu,K);
DF=mid(iDF);

A=intval(inv(DF));

A1a2=A(i1,i2); A1a4=A(i1,i4); A1a5=A(i1,i5); A1a6=A(i1,i6);
A2a2=A(i2,i2); A2a4=A(i2,i4); A2a5=A(i2,i5); A2a6=A(i2,i6);
A3a2=A(i3,i2); A3a4=A(i3,i4); A3a5=A(i3,i5); A3a6=A(i3,i6);
A4a2=A(i4,i2); A4a4=A(i4,i4); A4a5=A(i4,i5); A4a6=A(i4,i6);
A5a2=A(i5,i2); A5a4=A(i5,i4); A5a5=A(i5,i5); A5a6=A(i5,i6);
A6a2=A(i6,i2); A6a4=A(i6,i4); A6a5=A(i6,i5); A6a6=A(i6,i6);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%       Bounds Y       %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%display('Computing the Y bounds')
yF=abs(A*Fm);

vecteur_nu_1=nu.^intval(0:m1-1)';
vecteur_nu_4=nu.^intval(m1:4*m1-4)';
vecteur_nu_5=nu.^intval(m1:5*m1-5)';

Y1=sum(yF(1:m1).*vecteur_nu_1);
Y2=sum(yF(1:m1).*vecteur_nu_1)+L*sum(1./(m1:4*m1-4)'.*abs(F2_ext(m1+1:4*m1-3)).*vecteur_nu_4);
Y3=sum(yF(1:m1).*vecteur_nu_1);
Y4=sum(yF(1:m1).*vecteur_nu_1)+L*sum(1./(m1:4*m1-4)'.*abs(F4_ext(m1+1:4*m1-3)).*vecteur_nu_4);
Y5=sum(yF(1:m1).*vecteur_nu_1)+L*sum(1./(m1:5*m1-5)'.*abs(F5_ext(m1+1:5*m1-4)).*vecteur_nu_5);
Y6=sum(yF(1:m1).*vecteur_nu_1)+L*sum(1./(m1:5*m1-5)'.*abs(F6_ext(m1+1:5*m1-4)).*vecteur_nu_5);

%display(['Y1 = ',num2str(mag(Y1))])
%display(['Y2 = ',num2str(mag(Y2))])
%display(['Y3 = ',num2str(mag(Y3))])
%display(['Y4 = ',num2str(mag(Y4))])
%display(['Y5 = ',num2str(mag(Y5))])
%display(['Y6 = ',num2str(mag(Y6))])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%       Bounds Z       %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%
%%% Z^(0) %%%
%%%%%%%%%%%%%

%display('Computing B = I - A*DF')
B=abs(intval(eye(6*m))-A*iDF);

%display('Computing the Kji with interval arithmetic.')

Z10=Kji(B(i1,i1),nu)+Kji(B(i1,i2),nu)+Kji(B(i1,i3),nu)+Kji(B(i1,i4),nu)+Kji(B(i1,i5),nu)+Kji(B(i1,i6),nu);
Z20=Kji(B(i2,i1),nu)+Kji(B(i2,i2),nu)+Kji(B(i2,i3),nu)+Kji(B(i2,i4),nu)+Kji(B(i2,i5),nu)+Kji(B(i2,i6),nu);
Z30=Kji(B(i3,i1),nu)+Kji(B(i3,i2),nu)+Kji(B(i3,i3),nu)+Kji(B(i3,i4),nu)+Kji(B(i3,i5),nu)+Kji(B(i3,i6),nu);
Z40=Kji(B(i4,i1),nu)+Kji(B(i4,i2),nu)+Kji(B(i4,i3),nu)+Kji(B(i4,i4),nu)+Kji(B(i4,i5),nu)+Kji(B(i4,i6),nu);
Z50=Kji(B(i5,i1),nu)+Kji(B(i5,i2),nu)+Kji(B(i5,i3),nu)+Kji(B(i5,i4),nu)+Kji(B(i5,i5),nu)+Kji(B(i5,i6),nu);
Z60=Kji(B(i6,i1),nu)+Kji(B(i6,i2),nu)+Kji(B(i6,i3),nu)+Kji(B(i6,i4),nu)+Kji(B(i6,i5),nu)+Kji(B(i6,i6),nu);

%%%%%%%%%%%
% Z_j^(1) %
%%%%%%%%%%%

K1a2=Kji(A1a2,nu); K1a4=Kji(A1a4,nu); K1a5=Kji(A1a5,nu); K1a6=Kji(A1a6,nu);
K2a2=Kji(A2a2,nu); K2a4=Kji(A2a4,nu); K2a5=Kji(A2a5,nu); K2a6=Kji(A2a6,nu);
K3a2=Kji(A3a2,nu); K3a4=Kji(A3a4,nu); K3a5=Kji(A3a5,nu); K3a6=Kji(A3a6,nu);
K4a2=Kji(A4a2,nu); K4a4=Kji(A4a4,nu); K4a5=Kji(A4a5,nu); K4a6=Kji(A4a6,nu);
K5a2=Kji(A5a2,nu); K5a4=Kji(A5a4,nu); K5a5=Kji(A5a5,nu); K5a6=Kji(A5a6,nu);
K6a2=Kji(A6a2,nu); K6a4=Kji(A6a4,nu); K6a5=Kji(A6a5,nu); K6a6=Kji(A6a6,nu);

%display('Done computing the Kji.')

na1=norme_nu(a1,nu);
na2=norme_nu(a2,nu);
na3=norme_nu(a3,nu);
na4=norme_nu(a4,nu);
na5=norme_nu(a5,nu);
na6=norme_nu(a6,nu);

w3=[intval(zeros(m,1));nu.^-(m:3*m-3)'];
w4=[intval(zeros(m,1));nu.^-(m:4*m-4)'];
w5=[intval(zeros(m,1));nu.^-(m:5*m-5)'];

w3=[flip(w3(2:end),1);w3];
w4=[flip(w4(2:end),1);w4];
w5=[flip(w5(2:end),1);w5];

a1=abs(a1); a2=abs(a2); a3=abs(a3);
a4=abs(a4); a5=abs(a5); a6=abs(a6);

ta1_3m=[zeros(3*m-3,1);flip(a1(2:m),1);a1;zeros(3*m-3,1)];
ta1_4m=[zeros(4*m-4,1);flip(a1(2:m),1);a1;zeros(4*m-4,1)];

ta2_3m=[zeros(3*m-3,1);flip(a2(2:m),1);a2;zeros(3*m-3,1)];
ta2_4m=[zeros(4*m-4,1);flip(a2(2:m),1);a2;zeros(4*m-4,1)];

ta3_3m=[zeros(3*m-3,1);flip(a3(2:m),1);a3;zeros(3*m-3,1)];
ta3_4m=[zeros(4*m-4,1);flip(a3(2:m),1);a3;zeros(4*m-4,1)];

ta4_4m=[zeros(4*m-4,1);flip(a4(2:m),1);a4;zeros(4*m-4,1)];

ta5_2m=[zeros(2*m-2,1);flip(a5(2:m),1);a5;zeros(2*m-2,1)];
ta5_3m=[zeros(3*m-3,1);flip(a5(2:m),1);a5;zeros(3*m-3,1)];
ta5_4m=[zeros(4*m-4,1);flip(a5(2:m),1);a5;zeros(4*m-4,1)];

ta6_2m=[zeros(2*m-2,1);flip(a6(2:m),1);a6;zeros(2*m-2,1)];
ta6_3m=[zeros(3*m-3,1);flip(a6(2:m),1);a6;zeros(3*m-3,1)];
ta6_4m=[zeros(4*m-4,1);flip(a6(2:m),1);a6;zeros(4*m-4,1)];

%display('Computation of the FFT sums')

w_a5_2=int_cubic(w3,ta5_2m,ta5_2m);
w_a6_2=int_cubic(w3,ta6_2m,ta6_2m);

w_a5_3=int_quartic(w4,ta5_3m,ta5_3m,ta5_3m);
w_a6_3=int_quartic(w4,ta6_3m,ta6_3m,ta6_3m);
w_a1_a5_2=int_quartic(w4,ta1_3m,ta5_3m,ta5_3m);
w_a1_a6_2=int_quartic(w4,ta1_3m,ta6_3m,ta6_3m);
w_a2_a5_2=int_quartic(w4,ta2_3m,ta5_3m,ta5_3m);
w_a2_a6_2=int_quartic(w4,ta2_3m,ta6_3m,ta6_3m);
w_a3_a5_2=int_quartic(w4,ta3_3m,ta5_3m,ta5_3m);
w_a3_a6_2=int_quartic(w4,ta3_3m,ta6_3m,ta6_3m);

w_a1_a5_3=int_quintic(w5,ta1_4m,ta5_4m,ta5_4m,ta5_4m);
w_a2_a5_3=int_quintic(w5,ta2_4m,ta5_4m,ta5_4m,ta5_4m);
w_a3_a5_3=int_quintic(w5,ta3_4m,ta5_4m,ta5_4m,ta5_4m);
w_a4_a5_3=int_quintic(w5,ta4_4m,ta5_4m,ta5_4m,ta5_4m);
w_a1_a2_a5_2=int_quintic(w5,ta1_4m,ta2_4m,ta5_4m,ta5_4m);
w_a3_a4_a5_2=int_quintic(w5,ta3_4m,ta1_4m,ta5_4m,ta5_4m);
w_a1_a6_3=int_quintic(w5,ta1_4m,ta6_4m,ta6_4m,ta6_4m);
w_a2_a6_3=int_quintic(w5,ta2_4m,ta6_4m,ta6_4m,ta6_4m);
w_a3_a6_3=int_quintic(w5,ta3_4m,ta6_4m,ta6_4m,ta6_4m);
w_a4_a6_3=int_quintic(w5,ta4_4m,ta6_4m,ta6_4m,ta6_4m);
w_a1_a2_a6_2=int_quintic(w5,ta1_4m,ta2_4m,ta6_4m,ta6_4m);
w_a3_a4_a6_2=int_quintic(w5,ta3_4m,ta4_4m,ta6_4m,ta6_4m);

%display('Done with the computation of the FFT sums')

w_a5_2=w_a5_2(1:m); w_a5_3=w_a5_3(1:m); w_a6_2=w_a6_2(1:m); w_a6_3=w_a6_3(1:m);
w_a1_a5_2=w_a1_a5_2(1:m); w_a1_a6_2=w_a1_a6_2(1:m); w_a2_a5_2=w_a2_a5_2(1:m);
w_a2_a6_2=w_a2_a6_2(1:m); w_a3_a5_2=w_a3_a5_2(1:m); w_a3_a6_2=w_a3_a6_2(1:m);
w_a1_a5_3=w_a1_a5_3(1:m); w_a2_a5_3=w_a2_a5_3(1:m); w_a3_a5_3=w_a3_a5_3(1:m);
w_a4_a5_3=w_a4_a5_3(1:m); w_a1_a2_a5_2=w_a1_a2_a5_2(1:m); w_a3_a4_a5_2=w_a3_a4_a5_2(1:m);
w_a1_a6_3=w_a1_a6_3(1:m); w_a2_a6_3=w_a2_a6_3(1:m); w_a3_a6_3=w_a3_a6_3(1:m);
w_a4_a6_3=w_a4_a6_3(1:m); w_a1_a2_a6_2=w_a1_a2_a6_2(1:m); w_a3_a4_a6_2=w_a3_a4_a6_2(1:m);

eta1_term=(2/nu^m)*(abs(2*sum(a1)+mu)+abs(2*sum(a1)));
eta2_term=(2/nu^m)*(abs(2*sum(a1)+mu-1)+abs(2*sum(a1)));

alpha2=(1/(m*L))*(abs(mu-1)*na5^2*(na5+3*na1)+3*abs(mu^2-mu)*(na5^2+na6^2)+mu*na6^2*(na6+3*na1));
alpha4=(1/(m*L))*(abs(mu-1)*na5^2*(na5+3*na3)+mu*na6^2*(na6+3*na3));
alpha5=(1/(m*L))*(na5^3*(na1+na2+na3+na4+mu)+3*na5^2*(na1*na2+na3*na4+mu*na2));
alpha6=(1/(m*L))*(na6^3*(na1+na2+na3+na4+abs(mu-1))+3*na6^2*(na1*na2+na3*na4+abs(mu-1)*na2));

Z11=norme_nu(A1a5(:,1),nu)*eta1_term+norme_nu(A1a6(:,1),nu)*eta2_term...
    +6/(m*L)+abs(mu-1)*norme_nu(abs(A1a2)*w_a5_3,nu)+3*abs(mu-1)*norme_nu(abs(A1a2)*w_a1_a5_2,nu)+3*abs(mu^2-mu)*norme_nu(abs(A1a2)*w_a5_2,nu)+mu*norme_nu(abs(A1a2)*w_a6_3,nu)+3*mu*norme_nu(abs(A1a2)*w_a1_a6_2,nu)+3*abs(mu^2-mu)*norme_nu(abs(A1a2)*w_a6_2,nu)...
    +abs(mu-1)*norme_nu(abs(A1a4)*w_a5_3,nu)+3*abs(mu-1)*norme_nu(abs(A1a4)*w_a3_a5_2,nu)+mu*norme_nu(abs(A1a4)*w_a6_3,nu)+3*mu*norme_nu(abs(A1a4)*w_a3_a6_2,nu)...
    +norme_nu(abs(A1a5)*w_a1_a5_3,nu)+norme_nu(abs(A1a5)*w_a2_a5_3,nu)+norme_nu(abs(A1a5)*w_a3_a5_3,nu)+norme_nu(abs(A1a5)*w_a4_a5_3,nu)+3*norme_nu(abs(A1a5)*w_a1_a2_a5_2,nu)+3*norme_nu(abs(A1a5)*w_a3_a4_a5_2,nu)...
    +mu*norme_nu(abs(A1a5)*w_a5_3,nu)+3*mu*norme_nu(abs(A1a5)*w_a2_a5_2,nu)...
    +norme_nu(abs(A1a6)*w_a1_a6_3,nu)+norme_nu(abs(A1a6)*w_a2_a6_3,nu)+norme_nu(abs(A1a6)*w_a3_a6_3,nu)+norme_nu(abs(A1a6)*w_a4_a6_3,nu)+3*norme_nu(abs(A1a6)*w_a1_a2_a6_2,nu)+3*norme_nu(abs(A1a6)*w_a3_a4_a6_2,nu)...
    +abs(mu-1)*norme_nu(abs(A1a6)*w_a6_3,nu)+3*abs(mu-1)*norme_nu(abs(A1a6)*w_a2_a6_2,nu);

Z21=norme_nu(A2a5(:,1),nu)*eta1_term+norme_nu(A2a6(:,1),nu)*eta2_term...
    +6/(m*L)+abs(mu-1)*norme_nu(abs(A2a2)*w_a5_3,nu)+3*abs(mu-1)*norme_nu(abs(A2a2)*w_a1_a5_2,nu)+3*abs(mu^2-mu)*norme_nu(abs(A2a2)*w_a5_2,nu)+mu*norme_nu(abs(A2a2)*w_a6_3,nu)+3*mu*norme_nu(abs(A2a2)*w_a1_a6_2,nu)+3*abs(mu^2-mu)*norme_nu(abs(A2a2)*w_a6_2,nu)...
    +abs(mu-1)*norme_nu(abs(A2a4)*w_a5_3,nu)+3*abs(mu-1)*norme_nu(abs(A2a4)*w_a3_a5_2,nu)+mu*norme_nu(abs(A2a4)*w_a6_3,nu)+3*mu*norme_nu(abs(A2a4)*w_a3_a6_2,nu)...
    +norme_nu(abs(A2a5)*w_a1_a5_3,nu)+norme_nu(abs(A2a5)*w_a2_a5_3,nu)+norme_nu(abs(A2a5)*w_a3_a5_3,nu)+norme_nu(abs(A2a5)*w_a4_a5_3,nu)+3*norme_nu(abs(A2a5)*w_a1_a2_a5_2,nu)+3*norme_nu(abs(A2a5)*w_a3_a4_a5_2,nu)...
    +mu*norme_nu(abs(A2a5)*w_a5_3,nu)+3*mu*norme_nu(abs(A2a5)*w_a2_a5_2,nu)...
    +norme_nu(abs(A2a6)*w_a1_a6_3,nu)+norme_nu(abs(A2a6)*w_a2_a6_3,nu)+norme_nu(abs(A2a6)*w_a3_a6_3,nu)+norme_nu(abs(A2a6)*w_a4_a6_3,nu)+3*norme_nu(abs(A2a6)*w_a1_a2_a6_2,nu)+3*norme_nu(abs(A2a6)*w_a3_a4_a6_2,nu)...
    +abs(mu-1)*norme_nu(abs(A2a6)*w_a6_3,nu)+3*abs(mu-1)*norme_nu(abs(A2a6)*w_a2_a6_2,nu)+alpha2;

Z31=norme_nu(A3a5(:,1),nu)*eta1_term+norme_nu(A3a6(:,1),nu)*eta2_term...
    +6/(m*L)+abs(mu-1)*norme_nu(abs(A3a2)*w_a5_3,nu)+3*abs(mu-1)*norme_nu(abs(A3a2)*w_a1_a5_2,nu)+3*abs(mu^2-mu)*norme_nu(abs(A3a2)*w_a5_2,nu)+mu*norme_nu(abs(A3a2)*w_a6_3,nu)+3*mu*norme_nu(abs(A3a2)*w_a1_a6_2,nu)+3*abs(mu^2-mu)*norme_nu(abs(A3a2)*w_a6_2,nu)...
    +abs(mu-1)*norme_nu(abs(A3a4)*w_a5_3,nu)+3*abs(mu-1)*norme_nu(abs(A3a4)*w_a3_a5_2,nu)+mu*norme_nu(abs(A3a4)*w_a6_3,nu)+3*mu*norme_nu(abs(A3a4)*w_a3_a6_2,nu)...
    +norme_nu(abs(A3a5)*w_a1_a5_3,nu)+norme_nu(abs(A3a5)*w_a2_a5_3,nu)+norme_nu(abs(A3a5)*w_a3_a5_3,nu)+norme_nu(abs(A3a5)*w_a4_a5_3,nu)+3*norme_nu(abs(A3a5)*w_a1_a2_a5_2,nu)+3*norme_nu(abs(A3a5)*w_a3_a4_a5_2,nu)...
    +mu*norme_nu(abs(A3a5)*w_a5_3,nu)+3*mu*norme_nu(abs(A3a5)*w_a2_a5_2,nu)...
    +norme_nu(abs(A3a6)*w_a1_a6_3,nu)+norme_nu(abs(A3a6)*w_a2_a6_3,nu)+norme_nu(abs(A3a6)*w_a3_a6_3,nu)+norme_nu(abs(A3a6)*w_a4_a6_3,nu)+3*norme_nu(abs(A3a6)*w_a1_a2_a6_2,nu)+3*norme_nu(abs(A3a6)*w_a3_a4_a6_2,nu)...
    +abs(mu-1)*norme_nu(abs(A3a6)*w_a6_3,nu)+3*abs(mu-1)*norme_nu(abs(A3a6)*w_a2_a6_2,nu);

Z41=norme_nu(A4a5(:,1),nu)*eta1_term+norme_nu(A4a6(:,1),nu)*eta2_term...
    +6/(m*L)+abs(mu-1)*norme_nu(abs(A4a2)*w_a5_3,nu)+3*abs(mu-1)*norme_nu(abs(A4a2)*w_a1_a5_2,nu)+3*abs(mu^2-mu)*norme_nu(abs(A4a2)*w_a5_2,nu)+mu*norme_nu(abs(A4a2)*w_a6_3,nu)+3*mu*norme_nu(abs(A4a2)*w_a1_a6_2,nu)+3*abs(mu^2-mu)*norme_nu(abs(A4a2)*w_a6_2,nu)...
    +abs(mu-1)*norme_nu(abs(A4a4)*w_a5_3,nu)+3*abs(mu-1)*norme_nu(abs(A4a4)*w_a3_a5_2,nu)+mu*norme_nu(abs(A4a4)*w_a6_3,nu)+3*mu*norme_nu(abs(A4a4)*w_a3_a6_2,nu)...
    +norme_nu(abs(A4a5)*w_a1_a5_3,nu)+norme_nu(abs(A4a5)*w_a2_a5_3,nu)+norme_nu(abs(A4a5)*w_a3_a5_3,nu)+norme_nu(abs(A4a5)*w_a4_a5_3,nu)+3*norme_nu(abs(A4a5)*w_a1_a2_a5_2,nu)+3*norme_nu(abs(A4a5)*w_a3_a4_a5_2,nu)...
    +mu*norme_nu(abs(A4a5)*w_a5_3,nu)+3*mu*norme_nu(abs(A4a5)*w_a2_a5_2,nu)...
    +norme_nu(abs(A4a6)*w_a1_a6_3,nu)+norme_nu(abs(A4a6)*w_a2_a6_3,nu)+norme_nu(abs(A4a6)*w_a3_a6_3,nu)+norme_nu(abs(A4a6)*w_a4_a6_3,nu)+3*norme_nu(abs(A4a6)*w_a1_a2_a6_2,nu)+3*norme_nu(abs(A4a6)*w_a3_a4_a6_2,nu)...
    +abs(mu-1)*norme_nu(abs(A4a6)*w_a6_3,nu)+3*abs(mu-1)*norme_nu(abs(A4a6)*w_a2_a6_2,nu)+alpha4;

Z51=norme_nu(A5a5(:,1),nu)*eta1_term+norme_nu(A5a6(:,1),nu)*eta2_term...
    +6/(m*L)+abs(mu-1)*norme_nu(abs(A5a2)*w_a5_3,nu)+3*abs(mu-1)*norme_nu(abs(A5a2)*w_a1_a5_2,nu)+3*abs(mu^2-mu)*norme_nu(abs(A5a2)*w_a5_2,nu)+mu*norme_nu(abs(A5a2)*w_a6_3,nu)+3*mu*norme_nu(abs(A5a2)*w_a1_a6_2,nu)+3*abs(mu^2-mu)*norme_nu(abs(A5a2)*w_a6_2,nu)...
    +abs(mu-1)*norme_nu(abs(A5a4)*w_a5_3,nu)+3*abs(mu-1)*norme_nu(abs(A5a4)*w_a3_a5_2,nu)+mu*norme_nu(abs(A5a4)*w_a6_3,nu)+3*mu*norme_nu(abs(A5a4)*w_a3_a6_2,nu)...
    +norme_nu(abs(A5a5)*w_a1_a5_3,nu)+norme_nu(abs(A5a5)*w_a2_a5_3,nu)+norme_nu(abs(A5a5)*w_a3_a5_3,nu)+norme_nu(abs(A5a5)*w_a4_a5_3,nu)+3*norme_nu(abs(A5a5)*w_a1_a2_a5_2,nu)+3*norme_nu(abs(A5a5)*w_a3_a4_a5_2,nu)...
    +mu*norme_nu(abs(A5a5)*w_a5_3,nu)+3*mu*norme_nu(abs(A5a5)*w_a2_a5_2,nu)...
    +norme_nu(abs(A5a6)*w_a1_a6_3,nu)+norme_nu(abs(A5a6)*w_a2_a6_3,nu)+norme_nu(abs(A5a6)*w_a3_a6_3,nu)+norme_nu(abs(A5a6)*w_a4_a6_3,nu)+3*norme_nu(abs(A5a6)*w_a1_a2_a6_2,nu)+3*norme_nu(abs(A5a6)*w_a3_a4_a6_2,nu)...
    +abs(mu-1)*norme_nu(abs(A5a6)*w_a6_3,nu)+3*abs(mu-1)*norme_nu(abs(A5a6)*w_a2_a6_2,nu)+alpha5;

Z61=norme_nu(A6a5(:,1),nu)*eta1_term+norme_nu(A6a6(:,1),nu)*eta2_term...
    +6/(m*L)+abs(mu-1)*norme_nu(abs(A6a2)*w_a5_3,nu)+3*abs(mu-1)*norme_nu(abs(A6a2)*w_a1_a5_2,nu)+3*abs(mu^2-mu)*norme_nu(abs(A6a2)*w_a5_2,nu)+mu*norme_nu(abs(A6a2)*w_a6_3,nu)+3*mu*norme_nu(abs(A6a2)*w_a1_a6_2,nu)+3*abs(mu^2-mu)*norme_nu(abs(A6a2)*w_a6_2,nu)...
    +abs(mu-1)*norme_nu(abs(A6a4)*w_a5_3,nu)+3*abs(mu-1)*norme_nu(abs(A6a4)*w_a3_a5_2,nu)+mu*norme_nu(abs(A6a4)*w_a6_3,nu)+3*mu*norme_nu(abs(A6a4)*w_a3_a6_2,nu)...
    +norme_nu(abs(A6a5)*w_a1_a5_3,nu)+norme_nu(abs(A6a5)*w_a2_a5_3,nu)+norme_nu(abs(A6a5)*w_a3_a5_3,nu)+norme_nu(abs(A6a5)*w_a4_a5_3,nu)+3*norme_nu(abs(A6a5)*w_a1_a2_a5_2,nu)+3*norme_nu(abs(A6a5)*w_a3_a4_a5_2,nu)...
    +mu*norme_nu(abs(A6a5)*w_a5_3,nu)+3*mu*norme_nu(abs(A6a5)*w_a2_a5_2,nu)...
    +norme_nu(abs(A6a6)*w_a1_a6_3,nu)+norme_nu(abs(A6a6)*w_a2_a6_3,nu)+norme_nu(abs(A6a6)*w_a3_a6_3,nu)+norme_nu(abs(A6a6)*w_a4_a6_3,nu)+3*norme_nu(abs(A6a6)*w_a1_a2_a6_2,nu)+3*norme_nu(abs(A6a6)*w_a3_a4_a6_2,nu)...
    +abs(mu-1)*norme_nu(abs(A6a6)*w_a6_3,nu)+3*abs(mu-1)*norme_nu(abs(A6a6)*w_a2_a6_2,nu)+alpha6;

%%%%%%%%%%%
% Z_j^(2) %
%%%%%%%%%%%

Z12=8*(norme_nu(A1a5(:,1),nu)+norme_nu(A1a6(:,1),nu))...
    +4*(K1a2*(abs(mu-1)*(24*na5^2+24*na5*na1)+6*abs(mu-mu^2)*na5+6*mu*(4*na6^2+4*na6*na1)+abs(mu-mu^2)*(na6))...
    +K1a4*(abs(mu-1)*(24*na5^2+24*na5*na3)+6*mu*(4*na6^2+4*na6*na3))...
    +K1a5*(64*na5^3+4*na5^2*(24*na1+24*na2+24*na3+24*na4+6*mu)+na5*(24*mu*na2+96*na1*na2+96*na3*na4))...
    +K1a6*(64*na6^3+4*na6^2*(24*na1+24*na2+24*na3+24*na4+6*abs(mu-1))+na6*(24*mu*na2+96*na1*na2+96*na3*na4)));
Z22=8*(norme_nu(A2a5(:,1),nu)+norme_nu(A2a6(:,1),nu))...
    +4*(K2a2*(abs(mu-1)*(24*na5^2+24*na5*na1)+6*abs(mu-mu^2)*na5+6*mu*(4*na6^2+4*na6*na1)+abs(mu-mu^2)*(na6))...
    +K2a4*(abs(mu-1)*(24*na5^2+24*na5*na3)+6*mu*(4*na6^2+4*na6*na3))...
    +K2a5*(64*na5^3+4*na5^2*(24*na1+24*na2+24*na3+24*na4+6*mu)+na5*(24*mu*na2+96*na1*na2+96*na3*na4))...
    +K2a6*(64*na6^3+4*na6^2*(24*na1+24*na2+24*na3+24*na4+6*abs(mu-1))+na6*(24*mu*na2+96*na1*na2+96*na3*na4)));
Z32=8*(norme_nu(A3a5(:,1),nu)+norme_nu(A3a6(:,1),nu))...
    +4*(K3a2*(abs(mu-1)*(24*na5^2+24*na5*na1)+6*abs(mu-mu^2)*na5+6*mu*(4*na6^2+4*na6*na1)+abs(mu-mu^2)*(na6))...
    +K3a4*(abs(mu-1)*(24*na5^2+24*na5*na3)+6*mu*(4*na6^2+4*na6*na3))...
    +K3a5*(64*na5^3+4*na5^2*(24*na1+24*na2+24*na3+24*na4+6*mu)+na5*(24*mu*na2+96*na1*na2+96*na3*na4))...
    +K3a6*(64*na6^3+4*na6^2*(24*na1+24*na2+24*na3+24*na4+6*abs(mu-1))+na6*(24*mu*na2+96*na1*na2+96*na3*na4)));
Z42=8*(norme_nu(A4a5(:,1),nu)+norme_nu(A4a6(:,1),nu))...
    +4*(K4a2*(abs(mu-1)*(24*na5^2+24*na5*na1)+6*abs(mu-mu^2)*na5+6*mu*(4*na6^2+4*na6*na1)+abs(mu-mu^2)*(na6))...
    +K4a4*(abs(mu-1)*(24*na5^2+24*na5*na3)+6*mu*(4*na6^2+4*na6*na3))...
    +K4a5*(64*na5^3+4*na5^2*(24*na1+24*na2+24*na3+24*na4+6*mu)+na5*(24*mu*na2+96*na1*na2+96*na3*na4))...
    +K4a6*(64*na6^3+4*na6^2*(24*na1+24*na2+24*na3+24*na4+6*abs(mu-1))+na6*(24*mu*na2+96*na1*na2+96*na3*na4)));
Z52=8*(norme_nu(A5a5(:,1),nu)+norme_nu(A5a6(:,1),nu))...
    +4*(K5a2*(abs(mu-1)*(24*na5^2+24*na5*na1)+6*abs(mu-mu^2)*na5+6*mu*(4*na6^2+4*na6*na1)+abs(mu-mu^2)*(na6))...
    +K5a4*(abs(mu-1)*(24*na5^2+24*na5*na3)+6*mu*(4*na6^2+4*na6*na3))...
    +K5a5*(64*na5^3+4*na5^2*(24*na1+24*na2+24*na3+24*na4+6*mu)+na5*(24*mu*na2+96*na1*na2+96*na3*na4))...
    +K5a6*(64*na6^3+4*na6^2*(24*na1+24*na2+24*na3+24*na4+6*abs(mu-1))+na6*(24*mu*na2+96*na1*na2+96*na3*na4)));
Z62=8*(norme_nu(A6a5(:,1),nu)+norme_nu(A6a6(:,1),nu))...
    +4*(K6a2*(abs(mu-1)*(24*na5^2+24*na5*na1)+6*abs(mu-mu^2)*na5+6*mu*(4*na6^2+4*na6*na1)+abs(mu-mu^2)*(na6))...
    +K6a4*(abs(mu-1)*(24*na5^2+24*na5*na3)+6*mu*(4*na6^2+4*na6*na3))...
    +K6a5*(64*na5^3+4*na5^2*(24*na1+24*na2+24*na3+24*na4+6*mu)+na5*(24*mu*na2+96*na1*na2+96*na3*na4))...
    +K6a6*(64*na6^3+4*na6^2*(24*na1+24*na2+24*na3+24*na4+6*abs(mu-1))+na6*(24*mu*na2+96*na1*na2+96*na3*na4)));

%%%%%%%%%%%
% Z_j^(3) %
%%%%%%%%%%%

Z13=16*(K1a2*(9*abs(mu-1)*na5+9*mu*na6+3*abs(mu-1)*na1+3*mu*na1+3*abs(mu^2-mu))...
    +K1a4*(9*mu*na6+9*abs(1-mu)*na5+3*mu*na3)...
    +K1a5*(72*na5^2+9*na5*(4*na1+4*na2+4*na3+4*na4+mu)+3*mu*na2+12*na1*na2+12*na3*na4)...
    +K1a6*(72*na6^2+9*na6*(4*na1+4*na2+4*na3+4*na4+abs(mu-1))+3*abs(mu-1)*na2+12*na1*na2+12*na3*na4));
Z23=16*(K2a2*(9*abs(mu-1)*na5+9*mu*na6+3*abs(mu-1)*na1+3*mu*na1+3*abs(mu^2-mu))...
    +K2a4*(9*mu*na6+9*abs(1-mu)*na5+3*mu*na3)...
    +K2a5*(72*na5^2+9*na5*(4*na1+4*na2+4*na3+4*na4+mu)+3*mu*na2+12*na1*na2+12*na3*na4)...
    +K2a6*(72*na6^2+9*na6*(4*na1+4*na2+4*na3+4*na4+abs(mu-1))+3*abs(mu-1)*na2+12*na1*na2+12*na3*na4));
Z33=16*(K3a2*(9*abs(mu-1)*na5+9*mu*na6+3*abs(mu-1)*na1+3*mu*na1+3*abs(mu^2-mu))...
    +K3a4*(9*mu*na6+9*abs(1-mu)*na5+3*mu*na3)...
    +K3a5*(72*na5^2+9*na5*(4*na1+4*na2+4*na3+4*na4+mu)+3*mu*na2+12*na1*na2+12*na3*na4)...
    +K3a6*(72*na6^2+9*na6*(4*na1+4*na2+4*na3+4*na4+abs(mu-1))+3*abs(mu-1)*na2+12*na1*na2+12*na3*na4));
Z43=16*(K4a2*(9*abs(mu-1)*na5+9*mu*na6+3*abs(mu-1)*na1+3*mu*na1+3*abs(mu^2-mu))...
    +K4a4*(9*mu*na6+9*abs(1-mu)*na5+3*mu*na3)...
    +K4a5*(72*na5^2+9*na5*(4*na1+4*na2+4*na3+4*na4+mu)+3*mu*na2+12*na1*na2+12*na3*na4)...
    +K4a6*(72*na6^2+9*na6*(4*na1+4*na2+4*na3+4*na4+abs(mu-1))+3*abs(mu-1)*na2+12*na1*na2+12*na3*na4));
Z53=16*(K5a2*(9*abs(mu-1)*na5+9*mu*na6+3*abs(mu-1)*na1+3*mu*na1+3*abs(mu^2-mu))...
    +K5a4*(9*mu*na6+9*abs(1-mu)*na5+3*mu*na3)...
    +K5a5*(72*na5^2+9*na5*(4*na1+4*na2+4*na3+4*na4+mu)+3*mu*na2+12*na1*na2+12*na3*na4)...
    +K5a6*(72*na6^2+9*na6*(4*na1+4*na2+4*na3+4*na4+abs(mu-1))+3*abs(mu-1)*na2+12*na1*na2+12*na3*na4));
Z63=16*(K6a2*(9*abs(mu-1)*na5+9*mu*na6+3*abs(mu-1)*na1+3*mu*na1+3*abs(mu^2-mu))...
    +K6a4*(9*mu*na6+9*abs(1-mu)*na5+3*mu*na3)...
    +K6a5*(72*na5^2+9*na5*(4*na1+4*na2+4*na3+4*na4+mu)+3*mu*na2+12*na1*na2+12*na3*na4)...
    +K6a6*(72*na6^2+9*na6*(4*na1+4*na2+4*na3+4*na4+abs(mu-1))+3*abs(mu-1)*na2+12*na1*na2+12*na3*na4));

%%%%%%%%%%%
% Z_j^(4) %
%%%%%%%%%%%

Z14=64*(abs(8*mu-1)*K1a2+abs(8*mu-1)*K1a4+K1a5*(4*na1+4*na2+4*na3+4*na4+24*na5+4*mu)...
    +K1a6*(4*na1+4*na2+4*na3+4*na4+24*na6+4*abs(1-mu)));
Z24=64*(abs(8*mu-1)*K2a2+abs(8*mu-1)*K2a4+K2a5*(4*na1+4*na2+4*na3+4*na4+24*na5+4*mu)...
    +K2a6*(4*na1+4*na2+4*na3+4*na4+24*na6+4*abs(1-mu)));
Z34=64*(abs(8*mu-1)*K3a2+abs(8*mu-1)*K3a4+K3a5*(4*na1+4*na2+4*na3+4*na4+24*na5+4*mu)...
    +K3a6*(4*na1+4*na2+4*na3+4*na4+24*na6+4*abs(1-mu)));
Z44=64*(abs(8*mu-1)*K4a2+abs(8*mu-1)*K4a4+K4a5*(4*na1+4*na2+4*na3+4*na4+24*na5+4*mu)...
    +K4a6*(4*na1+4*na2+4*na3+4*na4+24*na6+4*abs(1-mu)));
Z54=64*(abs(8*mu-1)*K5a2+abs(8*mu-1)*K5a4+K5a5*(4*na1+4*na2+4*na3+4*na4+24*na5+4*mu)...
    +K5a6*(4*na1+4*na2+4*na3+4*na4+24*na6+4*abs(1-mu)));
Z64=64*(abs(8*mu-1)*K6a2+abs(8*mu-1)*K6a4+K6a5*(4*na1+4*na2+4*na3+4*na4+24*na5+4*mu)...
    +K6a6*(4*na1+4*na2+4*na3+4*na4+24*na6+4*abs(1-mu)));

%%%%%%%%%%%
% Z_j^(5) %
%%%%%%%%%%%

Z15=2560*(K1a5+K1a6);
Z25=2560*(K2a5+K2a6);
Z35=2560*(K3a5+K3a6);
Z45=2560*(K4a5+K4a6);
Z55=2560*(K5a5+K5a6);
Z65=2560*(K6a5+K6a6);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%      Computing the roots       %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%display(['Z11 = ',num2str(mag(Z11+Z10))])
%display(['Z12 = ',num2str(mag(Z21+Z20))])
%display(['Z13 = ',num2str(mag(Z31+Z30))])
%display(['Z14 = ',num2str(mag(Z41+Z40))])
%display(['Z15 = ',num2str(mag(Z51+Z50))])
%display(['Z16 = ',num2str(mag(Z61+Z60))])

%display(['Z21 = ',num2str(mag(Z12))])
%display(['Z22 = ',num2str(mag(Z22))])
%display(['Z23 = ',num2str(mag(Z32))])
%display(['Z24 = ',num2str(mag(Z42))])
%display(['Z25 = ',num2str(mag(Z52))])
%display(['Z26 = ',num2str(mag(Z62))])

p(1,:)=[mag(Z15),mag(Z14),mag(Z13),mag(Z12),mag(Z11+Z10)-1,mag(Y1)];
p(2,:)=[mag(Z25),mag(Z24),mag(Z23),mag(Z22),mag(Z21+Z20)-1,mag(Y2)];
p(3,:)=[mag(Z35),mag(Z34),mag(Z33),mag(Z32),mag(Z31+Z30)-1,mag(Y3)];
p(4,:)=[mag(Z45),mag(Z44),mag(Z43),mag(Z42),mag(Z41+Z40)-1,mag(Y4)];
p(5,:)=[mag(Z55),mag(Z54),mag(Z53),mag(Z52),mag(Z51+Z50)-1,mag(Y5)];
p(6,:)=[mag(Z65),mag(Z64),mag(Z63),mag(Z62),mag(Z61+Z60)-1,mag(Y6)];

I_1=roots(p(1,:));
I_2=roots(p(2,:));
I_3=roots(p(3,:));
I_4=roots(p(4,:));
I_5=roots(p(5,:));
I_6=roots(p(6,:));

I=[1,-1];
success=1;
r=0;

I_1=I_1(imag(I_1)==0);
I_1=I_1(real(I_1)>=0);
I_1=sort(I_1);

if isempty(I_1)==1
    display('Failure with polynomial # 1 ')
    success=0;
end

I_2=I_2(imag(I_2)==0);
I_2=I_2(real(I_2)>=0);
I_2=sort(I_2);

if isempty(I_2)==1
    display('Failure with polynomial # 2 ')
    success=0;
end

I_3=I_3(imag(I_3)==0);
I_3=I_3(real(I_3)>=0);
I_3=sort(I_3);

if isempty(I_3)==1
    display('Failure with polynomial # 3 ')
    success=0;
end

I_4=I_4(imag(I_4)==0);
I_4=I_4(real(I_4)>=0);
I_4=sort(I_4);

if isempty(I_4)==1
    display('Failure with polynomial # 4 ')
    success=0;
end

I_5=I_5(imag(I_5)==0);
I_5=I_5(real(I_5)>=0);
I_5=sort(I_5);

if isempty(I_5)==1
    display('Failure with polynomial # 5 ')
    success=0;
end

I_6=I_6(imag(I_6)==0);
I_6=I_6(real(I_6)>=0);
I_6=sort(I_6);

if isempty(I_6)==1
    display('Failure with polynomial # 6 ')
    success=0;
end

if success==0
    display('FAILURE! ')
else
    borne_inf=max([I_1(1),I_2(1),I_3(1),I_4(1),I_5(1),I_6(1)]);
    borne_sup=min([I_1(2),I_2(2),I_3(2),I_4(2),I_5(2),I_6(2)]);
    I=[borne_inf,borne_sup];
    if I(1)>=I(2)
        display('FAILURE because I(1)>=I(2)! ')
        success=0;
    else % We make sure that the polynomials are negative
        r=1.1*I(1);
        for k=1:6
            pr=sum(intval(p(k,:)).*intval(r).^(5:-1:0));
            if sup(pr)>=0
                display(['FAILURE p_k(r)>=0! at k = ',num2str(k)])
                success=0;
                return
            end
        end
        success=1;
    end
end

end

